@@ -165,7 +165,7 @@ class PooledDB(Pool_db.PooledDB):
             maxshared=0, maxconnections=0, blocking=False,
             maxusage=None, setsession=None, reset=True,
             failures=None, ping=1, test_on_borrow=False, test_idle=True,
-            validation_sql=None, idle_check_time=60, validate_timeout=1, max_wait_time=5,
+            validation_sql=None, idle_check_time=30, validate_timeout=1, max_wait_time=5,
             logger=None, *args, **kwargs):
         """Set up the DB-API 2 connection pool.
 
@@ -295,6 +295,7 @@ class PooledDB(Pool_db.PooledDB):
         :param time_out:
         :return:
         """
+        self._logger.debug("start_check_idle time_out:%s,_idle_cachesize=%s" % (time_out, len(self._idle_cache)))
         if not time_out:
             return False
 
@@ -323,8 +324,9 @@ class PooledDB(Pool_db.PooledDB):
         except Exception as e:
             self._logger.error("check idle conn error:%s" % e)
             return False
-        t = Timer(time_out, self.start_check_idle, [time_out])
-        t.start()
+        finally:
+            t = Timer(time_out, self.start_check_idle, [time_out])
+            t.start()
 
     def connection(self, shareable=True):
         # self._lock.acquire()
